@@ -16,10 +16,9 @@ CFSheet: A subclass of ProjectionSheet that provides an interface to
 the underlying ConnectionFields in any projection of type
 CFProjection.
 
-$Id: cf.py 11247 2010-07-18 20:39:43Z ceball $
+$Id$
 """
 
-__version__ = '$Revision: 11247 $'
 
 from copy import copy
 
@@ -75,8 +74,8 @@ def simple_vectorize(fn,num_outputs=1,output_type=object,doc=''):
 
 
 
-# Specified explicitly when creating weights matrix - required
-# for optimized C functions.
+#: Specified explicitly when creating weights matrix - required
+#: for optimized C functions.
 weight_type = Float32
 
 
@@ -105,9 +104,10 @@ class ConnectionField(object):
         See the norm_total property for more details.
         """
         # The actual value is cached in _norm_total.
-        if self._has_norm_total:
-            return self._norm_total
+        if self._has_norm_total[0]>0:
+            return self._norm_total[0]
         else:
+            # CEBALERT: what was I playing with for this before?
             return abs(self.weights).sum()
             
     def __set_norm_total(self,new_norm_total):
@@ -115,15 +115,15 @@ class ConnectionField(object):
         Set an explicit value to be returned by norm_total.
         See the norm_total property for more details.
         """
-        self._has_norm_total = True
-        self._norm_total = new_norm_total
+        self._has_norm_total[0] = 1
+        self._norm_total[0] = new_norm_total
 
     def __del_norm_total(self):
         """
         Delete any cached norm_total that may have been set.
         See the norm_total property for more details.
         """
-        self._has_norm_total = False
+        self._has_norm_total[0] = 0
 
 
     # CB: Accessing norm_total as a property from the C code takes
@@ -226,7 +226,8 @@ class ConnectionField(object):
         # http://docs.python.org/reference/datamodel.html). Can we
         # somehow avoid having to think about _has_norm_total in the
         # python code? Could the C code initialize this value?
-        self._has_norm_total=False
+        self._has_norm_total=array([0],dtype=numpy.int32)
+        self._norm_total=array([0.0],dtype=float)
 
         if output_fns is None:
             output_fns = []
@@ -612,6 +613,7 @@ class CFProjection(Projection):
     # CB: should be _initialize_cfs() since we already have 'initialize_cfs' flag?
     def _create_cfs(self):
         vectorized_create_cf = simple_vectorize(self._create_cf)
+        #:
         self.cfs = vectorized_create_cf(*self._generate_coords())
         self.flatcfs = list(self.cfs.flat)
 
@@ -1042,5 +1044,3 @@ class ResizableCFProjection(CFProjection):
             for of in output_fns:
                 of(cf.weights)
             del cf.norm_total
-
-
