@@ -11,31 +11,24 @@ to select a backend, or else select an appropriate one in your
 matplotlib.rc file (if any).  There are many backends available for
 different GUI or non-GUI uses.
 
-$Id: pylabplot.py 11144 2010-07-09 17:55:14Z ceball $
+$Id$
 """
-__version__='$Revision: 11144 $'
-
-# CEBALERT: these aren't being used
-import re
-import os
-import copy
-import errno
 
 import param
     
 try:
-    import matplotlib
+    import matplotlib.ticker
     import pylab
 except ImportError:
     param.Parameterized(name=__name__).warning("Could not import matplotlib; module will not be useable.")
-    from basic import ImportErrorRaisingFakeModule
-    pylab = ImportErrorRaisingFakeModule("matplotlib")
+    from topo.command import ImportErrorRaisingFakeModule
+    pylab = ImportErrorRaisingFakeModule("matplotlib")  # pyflakes:ignore (try/except import)
 
 
 import numpy
 from math import pi
 # JABALERT: Import all of these from numpy instead?
-from numpy.oldnumeric import arange, sqrt, array, floor, transpose, argmax, argmin, cos, sin, log10, Float
+from numpy.oldnumeric import sqrt, array, transpose, argmin, cos, sin, log10, Float
 from numpy import outer,arange,ones,zeros
 
 from numpy.fft.fftpack import fft2
@@ -44,24 +37,23 @@ from numpy import abs
 
 import topo
 from topo.base.sheetview import SheetView
-from topo.base.arrayutil import octave_output, centroid, wrap
+from topo.base.arrayutil import centroid, wrap
 from topo.base.sheet import Sheet
-from topo.base.arrayutil import wrap
 from topo.misc.util import frange
 import topo.analysis.vision
-from topo.plotting.plot import make_template_plot, Plot
+from topo.plotting.plot import make_template_plot
 import param
 from param import ParameterizedFunction,normalize_path
 from param.parameterized import ParamOverrides
-from topo.pattern.basic import SineGrating, RawRectangle, OrientationContrast
-from topo.plotting.plotgroup import create_plotgroup, plotgroups
+from topo.pattern import SineGrating, OrientationContrast
+from topo.plotting.plotgroup import create_plotgroup
 from topo.base.cf import CFSheet
 
-from topo.analysis.featureresponses import Feature, PatternPresenter, FeatureCurves
-from topo.analysis.featureresponses import SinusoidalMeasureResponseCommand, PositionMeasurementCommand, SingleInputResponseCommand, FeatureCurveCommand, UnitCurveCommand
+from topo.analysis.featureresponses import Feature, PatternPresenter
+from topo.analysis.featureresponses import PositionMeasurementCommand, FeatureCurveCommand, UnitCurveCommand
 
 
-from basic import Command
+from topo.command import Command
 
 
 
@@ -196,13 +188,24 @@ class matrixplot(PylabPlotCommand):
     plot_type = param.Callable(default=pylab.gray,doc="""
         Matplotlib command to generate the plot, e.g. pylab.gray or pylab.hsv.""")
     
+    extent = param.Parameter(default=None,doc="""
+        Subregion of the matrix to plot, as a tuple (l,b,r,t).""")
+    
     # JABALERT: All but the first two should probably be Parameters
     def __call__(self,mat,aspect=None,colorbar=True,**params):
         p=ParamOverrides(self,params)
         
         p.plot_type()
         pylab.figure(figsize=(5,5))
-        pylab.imshow(mat,interpolation='nearest',aspect=aspect)
+
+        # Swap lbrt to lrbt to match pylab
+        if p.extent is None:
+            extent = None
+        else:
+            (l,b,r,t)=p.extent
+            extent=(l,r,b,t)
+            
+        pylab.imshow(mat,interpolation='nearest',aspect=aspect,extent=extent)
         if colorbar and (mat.min()!= mat.max()): pylab.colorbar()
         self._generate_figure(p)
 
@@ -273,7 +276,6 @@ def matrixplot3d_gnuplot(mat,title=None,outputfilename="tmp.ps"):
     prompt is not available until this command finishes.
     """
     import Gnuplot
-    import Numeric # ERRORALERT
     from os import system
     
     psviewer="gv" # Should be a parameter, or handled better somehow
@@ -377,29 +379,36 @@ class fftplot(matrixplot):
         super(fftplot,self).__call__(fft_plot,**p)
 
         
-
-class activityplot(PylabPlotCommand):
+class autocorrelationplot(matrixplot):
     """
-    Plots the activity in a sheet.
-
-    Gets plot's extent from sheet.bounds.aarect(). Adds a title and
-    allows the selection of a colormap.  If activity is not given,
-    the sheet's current activity is used.
+    Compute and show the 2D autocorrelation of the supplied data.
+    Requires the external SciPy package.
+    
+    Example:: autocorrelationplot(topo.sim["V1"].sheet_views["OrientationPreference"].view()[0],filename="out")
     """
 
-    # JABALERT: All but the first two arguments should probably be Parameters    
-    # Not sure what this command is for or if anyone is using it.
-    def __call__(self,sheet,activity=None,cmap=None,**params):
+    plot_type = param.Callable(default=pylab.autumn)
+    
+    def __call__(self,data,**params):
         p=ParamOverrides(self,params)
+        import scipy.signal
+        mat=scipy.signal.correlate2d(data,data)
+        super(autocorrelationplot,self).__call__(mat,**p)
 
-        l,b,r,t = sheet.bounds.aarect().lbrt()
-        if activity is None:
-            activity = sheet.activity
-        if cmap is None:
-            cmap=pylab.cm.Greys
-        pylab.imshow(activity, extent=(l,r,b,t),cmap=cmap)
 
-        self._generate_figure(p)
+class activityplot(matrixplot):
+    """
+    Plots the activity in a sheet with axis labels in Sheet (not matrix) coordinates.
+
+    Same as matrixplot, but only for matrices associated with a Sheet.
+    By default plots the Sheet's activity, but any other matrix of the
+    same size may be supplied for plotting in these coordinates instead.
+    """
+    def __call__(self,sheet,mat=None,**params):
+        p=ParamOverrides(self,params)
+        if p.extent is None: p.extent=sheet.bounds.aarect().lbrt()
+        if mat is None: mat = sheet.activity
+        super(activityplot,self).__call__(mat,**p)
         
 
 
@@ -421,6 +430,12 @@ class topographic_grid(PylabPlotCommand):
     axis = param.Parameter(default=[-0.5,0.5,-0.5,0.5],doc="""
         Four-element list of the plot bounds, i.e. [xmin, xmax, ymin, ymax].""")
     
+    skip = param.Integer(default=1,bounds=[1,None],softbounds=[1,10],doc="""
+        Plot every skipth line in each direction.  
+        E.g. skip=4 means to keep only every fourth horizontal line
+        and every fourth vertical line, except that the first and last
+        are always included. The default is to include all data points.""")
+    
     def __call__(self,**params):
         p=ParamOverrides(self,params)
 
@@ -430,7 +445,7 @@ class topographic_grid(PylabPlotCommand):
     
                 x = sheet.sheet_views[p.xsheet_view_name].view()[0]
                 y = sheet.sheet_views[p.ysheet_view_name].view()[0]
-    
+                
                 pylab.figure(figsize=(5,5))
     
                 # This one-liner works in Octave, but in matplotlib it
@@ -441,10 +456,15 @@ class topographic_grid(PylabPlotCommand):
                 # see matplotlib for more info.
                 isint=pylab.isinteractive() # Temporarily make non-interactive for plotting
                 pylab.ioff()
-                for r,c in zip(y,x):
+                for r,c in zip(y[::p.skip],x[::p.skip]):
                     pylab.plot(c,r,"k-")
-                for r,c in zip(transpose(y),transpose(x)):
+                for r,c in zip(transpose(y)[::p.skip],transpose(x)[::p.skip]):
                     pylab.plot(c,r,"k-")
+
+                # Force last line avoid leaving cells open
+                if p.skip != 1:
+                    pylab.plot(x[-1],y[-1],"k-")
+                    pylab.plot(transpose(x)[-1],transpose(y)[-1],"k-")
                 
                 pylab.xlabel('x')
                 pylab.ylabel('y')
@@ -557,6 +577,9 @@ class tuning_curve(PylabPlotCommand):
     unit = param.String(default="",doc="""
         String to use in labels to specify the units in which curves are plotted.""")
 
+    legend=param.Boolean(default=True, doc="""
+        Whether or not to include a legend in the plot.""")
+
     __abstract = True
 
 
@@ -593,7 +616,7 @@ class tuning_curve(PylabPlotCommand):
         for coordinate in p.coords:
             i_value,j_value=sheet.sheet2matrixidx(coordinate[0],coordinate[1])
         
-            f = pylab.figure(figsize=(7,7))
+            pylab.figure(figsize=(7,7))
             isint=pylab.isinteractive()
             pylab.ioff()
     
@@ -615,7 +638,7 @@ class tuning_curve(PylabPlotCommand):
                 self.first_curve=False
                  
             if isint: pylab.ion()
-            pylab.legend(loc=2)
+            if p.legend: pylab.legend(loc=2)
             self._generate_figure(p)
 
 
@@ -808,24 +831,23 @@ class plot_modulation_ratio(PylabPlotCommand):
         if (topo.sim.objects().has_key(simple_sheet_name) and topo.sim.objects().has_key(complex_sheet_name)):
             v1s = complexity(fullmatrix[topo.sim[simple_sheet_name]]).flatten()
             v1c = complexity(fullmatrix[topo.sim[complex_sheet_name]]).flatten()
-            import matplotlib.ticker as mticker
             #double the number of complex cells to reflect large width of layer 2/3
             v1c = numpy.concatenate((array(v1c),array(v1c)),axis=1)
             pylab.figure()
             n = pylab.subplot(311)
             pylab.hist(v1s,bins)
             pylab.axis([0,2.0,0,4100])
-	    n.yaxis.set_major_locator(mticker.MaxNLocator(3))
+	    n.yaxis.set_major_locator(matplotlib.ticker.MaxNLocator(3))
             
 	    n = pylab.subplot(312)
             pylab.hist(v1c,bins)
             pylab.axis([0,2.0,0,4100])
-	    n.yaxis.set_major_locator(mticker.MaxNLocator(3))
+	    n.yaxis.set_major_locator(matplotlib.ticker.MaxNLocator(3))
             
 	    n = pylab.subplot(313)
             pylab.hist(numpy.concatenate((array(v1s),array(v1c)),axis=1),bins)
             pylab.axis([0,2.0,0,4100])
-	    n.yaxis.set_major_locator(mticker.MaxNLocator(3))
+	    n.yaxis.set_major_locator(matplotlib.ticker.MaxNLocator(3))
 
         self._generate_figure(p)
 
@@ -839,13 +861,15 @@ class measure_position_pref(PositionMeasurementCommand):
     def _feature_list(self,p):
         width =1.0*p.x_range[1]-p.x_range[0]
         height=1.0*p.y_range[1]-p.y_range[0]
-        return [Feature(name="x",range=p.x_range,step=width/p.divisions),
-                Feature(name="y",range=p.y_range,step=height/p.divisions)]
+        return [Feature(name="x",range=p.x_range,step=width/p.divisions,preference_fn=self.preference_fn),
+                Feature(name="y",range=p.y_range,step=height/p.divisions,preference_fn=self.preference_fn)]
 
 
+from topo.misc.distribution import DSF_WeightedAverage
 pg= create_plotgroup(name='Position Preference',category="Preference Maps",
            doc='Measure preference for the X and Y position of a Gaussian.',
-           pre_plot_hooks=[measure_position_pref.instance()],
+           pre_plot_hooks=[measure_position_pref.instance(
+            preference_fn=DSF_WeightedAverage( selectivity_scale=(0.,17.) ))],
            plot_hooks=[topographic_grid.instance()],
            normalize='Individually')
 
@@ -1063,7 +1087,7 @@ class measure_size_response(UnitCurveCommand):
     def _feature_list(self,p):
         return [Feature(name="phase",range=(0.0,2*pi),step=2*pi/p.num_phase,cyclic=True),
                 Feature(name="frequency",values=p.frequencies),
-                Feature(name="size",range=(0.0,self.max_size),step=1.0/p.num_sizes,cyclic=False)]
+                Feature(name="size",range=(0.0,self.max_size),step=self.max_size/p.num_sizes,cyclic=False)]
 
 
 create_plotgroup(template_plot_type="curve",name='Size Tuning',category="Tuning Curves",
@@ -1232,4 +1256,3 @@ __all__ = list(set([k for k,v in locals().items()
                     if isinstance(v,types.FunctionType) or 
                     (isinstance(v,type) and issubclass(v,ParameterizedFunction))
                     and not v.__name__.startswith('_')]))
-
