@@ -1,12 +1,11 @@
 """
-Learning functions (see basic.py) and projection-level learning
-functions (see projfn.py) written in C to optimize performance.
+Learning functions and projection-level learning functions (see projfn.py)
+written in C to optimize performance.
 
 Requires the weave package; without it unoptimized versions are used.
 
-$Id: optimized.py 10867 2010-01-31 18:55:35Z ceball $
+$Id$
 """
-__version__ = "$Revision: 10867 $"
 
 from numpy import zeros, ones
 
@@ -16,10 +15,11 @@ from topo.base.sheet import activity_type
 from topo.base.cf import CFPLearningFn,CFPLF_Plugin
 from topo.learningfn.projfn import CFPLF_PluginScaled
 from topo.base.functionfamily import Hebbian,LearningFn
-from topo.misc.inlinec import inline,provide_unoptimized_equivalent,c_header
-from topo.learningfn.basic import BCMFixed
+from topo.misc.inlinec import inline,provide_unoptimized_equivalent,\
+     c_header,c_decorators
+from topo.learningfn import BCMFixed
 
-from projfn import CFPLF_Trace
+from projfn import CFPLF_Trace  # pyflakes:ignore (optimized version provided)
 
 
 
@@ -46,9 +46,9 @@ class CFPLF_Hebbian_opt(CFPLearningFn):
             return
 
         cfs = iterator.flatcfs
-        num_cfs = len(cfs)
+        num_cfs = len(cfs)  # pyflakes:ignore (passed to weave C code)
         irows,icols = input_activity.shape
-        cf_type = iterator.cf_type
+        cf_type = iterator.cf_type  # pyflakes:ignore (passed to weave C code)
 
         # CEBALERT: this function *always* skips inactive units,
         # because it uses the output_activity directly rather than
@@ -59,20 +59,19 @@ class CFPLF_Hebbian_opt(CFPLearningFn):
         # iterator's active_units_mask to be True before calling the
         # iterator in the unoptimized version.)
 
-        sheet_mask = iterator.get_sheet_mask()
+        sheet_mask = iterator.get_sheet_mask()  # pyflakes:ignore (passed to weave C code)
 
         code = c_header + """
             DECLARE_SLOT_OFFSET(weights,cf_type);
             DECLARE_SLOT_OFFSET(input_sheet_slice,cf_type);
             DECLARE_SLOT_OFFSET(mask,cf_type);
+            DECLARE_SLOT_OFFSET(_norm_total,cf_type);
+            DECLARE_SLOT_OFFSET(_has_norm_total,cf_type);
 
-            npfloat *x = output_activity;
-            npfloat *m = sheet_mask;
-
+            %(cfs_loop_pragma)s
             for (int r=0; r<num_cfs; ++r) {
-                double load = *x++;
-                double msk = *m++;
-                if (load != 0 && msk != 0) {
+                double load = output_activity[r];
+                if (load != 0 && sheet_mask[r] != 0) {
                     load *= single_connection_learning_rate;
 
                     PyObject *cf = PyList_GetItem(cfs,r);
@@ -101,16 +100,15 @@ class CFPLF_Hebbian_opt(CFPLearningFn):
                             ++inpi;
                         }
                         inpj += icols;
-                    }
-
+                    }                    
                     // store the sum of the cf's weights
-                    PyObject *total_obj = PyFloat_FromDouble(total);  //(new ref)
-                    PyObject_SetAttrString(cf,"_norm_total",total_obj);
-                    PyObject_SetAttrString(cf,"_has_norm_total",Py_True);
-                    Py_DECREF(total_obj);
+                    LOOKUP_FROM_SLOT_OFFSET(double,_norm_total,cf);
+                    _norm_total[0]=total;
+                    LOOKUP_FROM_SLOT_OFFSET(int,_has_norm_total,cf);
+                    _has_norm_total[0]=1;
                 }
             }
-        """
+        """%c_decorators
 
         inline(code, ['input_activity', 'output_activity','sheet_mask','num_cfs',
                       'icols', 'cfs', 'single_connection_learning_rate','cf_type'],
@@ -147,15 +145,15 @@ class CFPLF_BCMFixed_opt(CFPLearningFn):
     def __call__(self, iterator, input_activity, output_activity, learning_rate, **params):
         rows,cols = output_activity.shape
         cfs = iterator.flatcfs
-        num_cfs = len(cfs)
+        num_cfs = len(cfs)  # pyflakes:ignore (passed to weave C code)
         single_connection_learning_rate = self.constant_sum_connection_rate(iterator.proj_n_units,learning_rate)
         if single_connection_learning_rate==0:
             return
         
-        unit_threshold=self.unit_threshold
+        unit_threshold=self.unit_threshold  # pyflakes:ignore (passed to weave C code)
         
         irows,icols = input_activity.shape
-        cf_type = iterator.cf_type
+        cf_type = iterator.cf_type  # pyflakes:ignore (passed to weave C code)
         code = c_header + """
             // CEBALERT: should provide a macro for getting offset
 
@@ -260,10 +258,10 @@ class CFPLF_Scaled_opt(CFPLF_PluginScaled):
         if self.learning_rate_scaling_factor is None:
             self.learning_rate_scaling_factor = ones(output_activity.shape)*1.0
 
-        learning_rate_scaling_factor = self.learning_rate_scaling_factor
+        learning_rate_scaling_factor = self.learning_rate_scaling_factor  # pyflakes:ignore (passed to weave C code)
 
         cfs = iterator.flatcfs
-        num_cfs = len(cfs)
+        num_cfs = len(cfs)  # pyflakes:ignore (passed to weave C code)
         single_connection_learning_rate = self.constant_sum_connection_rate(iterator.proj_n_units,learning_rate)
         if single_connection_learning_rate==0:
             return
@@ -350,7 +348,7 @@ class CFPLF_Trace_opt(CFPLearningFn):
         doc="LearningFn that will be applied to each CF individually.")              
 
     def __call__(self, iterator, input_activity, output_activity, learning_rate, **params):
-        cfs = iterator.flatcfs
+        cfs = iterator.flatcfs  # pyflakes:ignore (passed to weave C code)
         single_connection_learning_rate = self.constant_sum_connection_rate(iterator.proj_n_units,learning_rate)
         irows,icols = input_activity.shape
         
@@ -362,7 +360,7 @@ class CFPLF_Trace_opt(CFPLearningFn):
             self.traces=zeros(output_activity.shape,activity_type)
         
         self.traces = (self.trace_strength*output_activity)+((1-self.trace_strength)*self.traces)
-        traces = self.traces
+        traces = self.traces  # pyflakes:ignore (passed to weave C code)
         
         code = c_header + """
             npfloat *x = traces;
