@@ -7,15 +7,14 @@ specifying ways of generating 1D-vs-time traces from recorded data,
 and a TraceGroup object that will plot a set of traces on stacked,
 aligned axes.
 
-$Id: trace.py 11137 2010-07-07 03:34:18Z ceball $
+$Id$
 """
-__version__ = '$Revision: 11137 $'
 
 import os
 import bisect
 from itertools import izip
 
-from numpy import array,asarray
+from numpy import asarray
 import ImageDraw
 
 import param
@@ -426,6 +425,7 @@ def get_images(name,times,recorder,overlays=(0,0,0)):
 
 # JABALERT: Is there some reason it is called ActivityMovie in
 # particular, if it can plot things other than Activity?
+# Maybe DataRecorderMovie?
 class ActivityMovie(param.Parameterized):
     """
     An object encapsulating a series of movie frames displaying the
