@@ -1,28 +1,21 @@
 """
 LISSOM and related sheet classes.
 
-$Id: lissom.py 10871 2010-01-31 19:01:06Z ceball $
+$Id$
 """
-__version__='$Revision: 10871 $'
 
-import numpy.oldnumeric as Numeric
-import numpy
-from numpy import abs,zeros,ones
+from numpy import zeros,ones
 import copy
 
 import param
 
 import topo
-from topo.base.boundingregion import BoundingBox
-from topo.base.functionfamily import TransferFn
-from topo.base.cf import CFSheet, CFPOutputFn
+
 from topo.base.projection import Projection
 from topo.base.sheet import activity_type
 from topo.base.simulation import EPConnectionEvent
-from topo.misc.keyedlist import KeyedList
-from topo.transferfn.basic import PiecewiseLinear
-from topo.sheet import JointNormalizingCFSheet, JointNormalizingCFSheet_Continuous
-from topo.pattern.basic import Gaussian
+from topo.transferfn import PiecewiseLinear
+from topo.sheet import JointNormalizingCFSheet
 
 
 class LISSOM(JointNormalizingCFSheet):
@@ -110,6 +103,8 @@ class LISSOM(JointNormalizingCFSheet):
     ### settle at all after the first iteration?), but of course that
     ### is arguably an error condition anyway (and should thus be
     ### flagged).
+    # CEBALERT: there is at least one bug in here for tsettle==0: see
+    # CB/JAB email "LISSOM tsettle question", 2010/03/22.
     def process_current_time(self):
         """
         Pass the accumulated stimulation through self.output_fns and
@@ -173,7 +168,7 @@ class LISSOM(JointNormalizingCFSheet):
                        continue
             self.verbose("Sending output on src_port %s via connection %s to %s" %
                          (str(src_port), conn.name, conn.dest.name))
-            e=EPConnectionEvent(conn.delay+self.simulation.time(),conn,data)
+            e=EPConnectionEvent(self.simulation.convert_to_time_type(conn.delay)+self.simulation.time(),conn,data)
             self.simulation.enqueue_event(e)
 
 
@@ -436,3 +431,10 @@ def schedule_events(sheet_str="topo.sim['V1']",st=0.5,aff_name="Afferent",
     topo.sim.schedule_command( 5000*st,sheet_str+'.tsettle=11')
     topo.sim.schedule_command( 6500*st,sheet_str+'.tsettle=12')
     topo.sim.schedule_command( 8000*st,sheet_str+'.tsettle=13')
+
+
+__all__ = [
+    "LISSOM",
+    "JointScaling",
+    "schedule_events",
+]
