@@ -7,22 +7,21 @@ Window:  window and canvas
 
 Originally written by Alan Lindsay.
 
-$Id: editor.py 11137 2010-07-07 03:34:18Z ceball $
+$Id$
 """
 __version__='$Revision: 8989 $'
 
 from inspect import getdoc
 import math
-from random import Random, random
 
-
-from Tkinter import Button, Label, Frame, TOP, LEFT, RIGHT, BOTTOM, E, LAST, FIRST, OptionMenu, StringVar,Canvas,X,GROOVE,RAISED,Checkbutton,Menu,Scrollbar, SUNKEN,YES,Y,END,BOTH
+from Tkinter import Button, Label, Frame, TOP, LEFT, RIGHT, BOTTOM, E, LAST, FIRST, OptionMenu, StringVar,Canvas,X,GROOVE,RAISED,Checkbutton,Menu,Scrollbar, YES,Y,END,BOTH
 from tkFileDialog import asksaveasfilename
 
 
 import param
-from param import tk,parameterized,normalize_path
-from param.external import Combobox
+from param import parameterized,normalize_path
+import paramtk as tk
+from paramtk.tilewrapper import Combobox
 
 import topo
 from topo.command.analysis import update_activity
@@ -78,11 +77,22 @@ class EditorCanvas(Canvas):
 
         self.normalize_checkbutton = Checkbutton(self.panel, text="Normalize",
                                                     command=self.toggle_normalize)
-
         self.normalize_checkbutton.pack(side=LEFT)
         if EditorSheet.normalize == True:
             self.normalize_checkbutton.select()
 
+        self.node_labels_checkbutton = Checkbutton(self.panel, text="Node labels",
+                                                    command=self.toggle_node_labels)
+        self.node_labels_checkbutton.pack(side=LEFT)
+        if EditorNode.show_label == True:
+            self.node_labels_checkbutton.select()
+
+        self.connection_labels_checkbutton = Checkbutton(self.panel, text="Connection labels",
+                                                    command=self.toggle_connection_labels)
+        self.connection_labels_checkbutton.pack(side=LEFT)
+        if EditorConnection.show_label == True:
+            self.connection_labels_checkbutton.select()
+
         # retain the current focus in the canvas
         self.scaling_factor = topo.sim.item_scale#scaling_factor
         self.current_object = None
@@ -270,6 +280,14 @@ class EditorCanvas(Canvas):
         EditorSheet.normalize = not EditorSheet.normalize
         self.refresh()
 
+    def toggle_node_labels(self):
+        EditorNode.show_label = not EditorNode.show_label
+        self.refresh()
+
+    def toggle_connection_labels(self):
+        EditorConnection.show_label = not EditorConnection.show_label
+        self.refresh()
+
 
 
     #   Object moving methods
@@ -999,6 +1017,7 @@ class EditorObject(object):
         self.name = name # set the name of the sheet
         self.focus = False # this does not have the focus
         self.viewing_choices = []
+        self.label=None
 
     def draw(self):
         "Draw the object at the current x, y position."
@@ -1064,6 +1083,8 @@ class EditorNode(EditorObject):
     in a EditorCanvas. Extending classes will supply a draw method and other type specific 
     attributes. 
     """
+    show_label= param.Boolean(default=True,
+        doc="Whether to show a textual label for this object")
 
     def __init__(self, canvas, simobj, pos, name):
         EditorObject.__init__(self, name, canvas)
@@ -1140,7 +1161,7 @@ class EditorEP(EditorNode):
     """
     Represents any topo EventProcessor as a small, fixed-size oval by default.
     """
-    
+
     def __init__(self, canvas, simobj, pos, name):
         EditorNode.__init__(self, canvas, simobj, pos, name)
         simobj.layout_location = (self.x,self.y) # store the ed coords in the topo sheet
@@ -1152,7 +1173,6 @@ class EditorEP(EditorNode):
         self.currentCol = col
         self.gradient = 1
 
-
     #   Draw methods
 
     def set_focus(self, focus):
@@ -1187,7 +1207,8 @@ class EditorEP(EditorNode):
 
         self.id = [self.canvas.create_oval(x1,y1,x2,y2,fill=colour,outline="black")]
         dX = w + 5
-        self.label = self.canvas.create_text(x - dX, y, anchor = E, fill = label_colour, text = self.name)
+        if (self.show_label):
+            self.label = self.canvas.create_text(x - dX, y, anchor = E, fill = label_colour, text = self.name)
 
     def dec_to_hex_str(self, val, length):
         # expects a normalised value and maps it to a hex value of the given length
@@ -1200,10 +1221,12 @@ class EditorEP(EditorNode):
         if not(x == y == 0):
             for id in self.id:
                 self.canvas.move(id, x, y)
-            self.canvas.move(self.label, x, y)
+            if (self.show_label):
+                self.canvas.move(self.label, x, y)
         for id in self.id:
             self.canvas.tag_raise(id)
-        self.canvas.tag_raise(self.label)
+        if (self.show_label):
+            self.canvas.tag_raise(self.label)
         # redraw the connections
         for con in self.to_connections : 
             if (con.from_node == con.to_node):
@@ -1273,8 +1296,6 @@ class EditorEP(EditorNode):
     #   Util methods
 
     def in_bounds(self, pos_x, pos_y):
-        x = self.x - pos_x; y = self.y - pos_y
-        
         return ((pos_x> self.x-self.width)  and (pos_x<= self.x+self.width) and 
                 (pos_y> self.y-self.height) and (pos_y<= self.y+self.height))
 
@@ -1378,7 +1399,8 @@ class EditorSheet(EditorEP):
         self.id = self.id + [self.canvas.create_polygon(x1, y1, x2, y2, x3, y3, x4, y4, 
             fill = colour , outline = "black")]
         dX = w + 5
-        self.label = self.canvas.create_text(x - dX, y, anchor = E, fill = label_colour, text = self.name)
+        if (self.show_label):
+            self.label = self.canvas.create_text(x - dX, y, anchor = E, fill = label_colour, text = self.name)
         # adds a density grid over the sheet
         if self.show_density:
             x, y = self.x - w + h, self.y - h
@@ -1469,6 +1491,10 @@ class EditorConnection(EditorObject):
     to cover any topographica connection (connection / projection), and extending 
     classes will supply a draw method and other type specific attributes.
     """
+
+    show_label= param.Boolean(default=True,
+        doc="Whether to show a textual label for this object")
+
     def __init__(self, name, canvas, from_node):
         EditorObject.__init__(self, name, canvas)
         self.from_node = from_node # initial node selected
@@ -1526,6 +1552,7 @@ class EditorEPConnection(EditorConnection):
     """
     Represents any topo EPConnection using a line with an arrow head in the middle.
     """ 
+
     def __init__(self, name, canvas, from_node):
         EditorConnection.__init__(self, name, canvas, from_node)
         # if more than one connection between nodes, 
@@ -1534,7 +1561,6 @@ class EditorEPConnection(EditorConnection):
         self.deviation = 0
         self.gradient = (1,1)
         self.id = (None,None)
-        self.label = None
         self.balloon = tk.Balloon(canvas)
         self.set_colours()
         self.view = 'line'
@@ -1542,7 +1568,6 @@ class EditorEPConnection(EditorConnection):
         self.viewing_choices = [('Line', lambda: self.select_view('line'))]
         self.update_factor()
 
-
     #   Draw methods
     
     def select_view(self, view_choice):
@@ -1573,11 +1598,9 @@ class EditorEPConnection(EditorConnection):
         # set the colour to be used depending on whether connection has the focus.
         if (self.focus) : 
             text_col = col = self.colour[0]
-            lateral_colour = self.from_node.colour[0]
         else:
             text_col = 'black'
             col = self.colour[1]
-            lateral_colour = ''
         middle = self.get_middle(from_position, to_position)
         factor = self.canvas.scaling_factor
         if (to_position == from_position) : # connection to and from the same node
@@ -1591,8 +1614,9 @@ class EditorEPConnection(EditorConnection):
             self.id = (self.canvas.create_oval(x1, y1, x2, y2, outline = col), 
             self.canvas.create_line(midX, y1, midX+1, y1, arrow = FIRST, fill = col))
             # draw name label beside arrow head
-            self.label = self.canvas.create_text(middle[0] - 
-            (20 + len(self.name)*3), middle[1] - (30 + deviation) , text = self.name)
+            if (self.show_label):
+                self.label = self.canvas.create_text(middle[0] - 
+                    (20 + len(self.name)*3), middle[1] - (30 + deviation) , text = self.name)
         else :    
             # create a line between the nodes - use 2 to make arrow in center.
             dev = self.deviation
@@ -1603,8 +1627,9 @@ class EditorEPConnection(EditorConnection):
             # draw name label
             dX = 20 * factor
             dY = self.draw_index * 20 * factor
-            self.label = self.canvas.create_text(middle[0] - dX,
-                middle[1] - dY, fill = text_col, text = self.name, anchor = E)
+            if (self.show_label):
+                self.label = self.canvas.create_text(middle[0] - dX,
+                    middle[1] - dY, fill = text_col, text = self.name, anchor = E)
 
 
     #   Update methods
@@ -1735,7 +1760,6 @@ class EditorProjection(EditorEPConnection):
             lateral_colour = ''
         # midpoint of line
         middle = self.get_middle(from_position, to_position)
-        factor = self.canvas.scaling_factor
         if (to_position == from_position) : # connection to and from the same node
             a, b = self.get_radius()
             x1 = to_position[0] - a
@@ -1760,8 +1784,9 @@ class EditorProjection(EditorEPConnection):
             # draw name label
             dX = 20
             dY = self.draw_index * 20
-            self.label = self.canvas.create_text(middle[0] - dX,
-                middle[1] - dY, fill = text_col, text = self.name, anchor = E)
+            if (self.show_label):
+                self.label = self.canvas.create_text(middle[0] - dX,
+                    middle[1] - dY, fill = text_col, text = self.name, anchor = E)
 
 
     def draw_normal(self, from_position, to_position):
@@ -1798,8 +1823,9 @@ class EditorProjection(EditorEPConnection):
             # draw name label
             dX = 20
             dY = self.draw_index * 20
-            self.label = self.canvas.create_text(middle[0] - dX,
-                middle[1] - dY, fill = text_col, text = self.name, anchor = E)
+            if (self.show_label):
+                self.label = self.canvas.create_text(middle[0] - dX,
+                    middle[1] - dY, fill = text_col, text = self.name, anchor = E)
         
 
     #   Util methods
@@ -1889,12 +1915,12 @@ class EditorProjection(EditorEPConnection):
                 A = (to_position[0] - x, to_position[1] - y)
                 T = (from_position[0] + (self.deviation * factor) - x, from_position[1] - y)
                 B = (T[0] - self.radius[0], T[1])
-                C = (T[0] + self.radius[0], T[1])
+                #C = (T[0] + self.radius[0], T[1])
             else:
                 A = (to_position[0] - x, to_position[1] - y)
                 T = (from_position[0] + (self.deviation * factor) - x, from_position[1] - y)
                 B = (T[0] - (self.normal_radius * factor), T[1])
-                C = (T[0] + (self.normal_radius * factor), T[1])
+                #C = (T[0] + (self.normal_radius * factor), T[1])
             # if the y coords lie outwith the boundaries, return false
             if (((A[1] < B[1]) and (B[1] < 0 or A[1] > 0)) or 
                 ((A[1] >= B[1]) and (B[1] > 0 or A[1] < 0))):
