@@ -2,9 +2,8 @@
 TopoConsole class file.
 
 
-$Id: topoconsole.py 11264 2010-07-21 18:12:49Z ceball $
+$Id$
 """
-__version__='$Revision: 11264 $'
 
 
 # CB: does the status bar need to keep saying 'ok'? Sometimes
@@ -18,15 +17,14 @@ import __main__
 import webbrowser
 import string
 
-from inspect import getdoc
-
-from Tkinter import Frame, StringVar, X, BOTTOM, TOP, Button, \
-     LEFT, RIGHT, YES, NO, BOTH, Label, Text, END, DISABLED, \
-     NORMAL, Scrollbar, Y, DoubleVar, Widget
+from Tkinter import Frame, Button, \
+     LEFT, YES, Label, DISABLED, \
+     NORMAL, DoubleVar
 from tkFileDialog import asksaveasfilename,askopenfilename
 
 import param
-from param import tk,normalize_path,resolve_path
+from param import normalize_path,resolve_path
+import paramtk as tk
 
 
 import topo
@@ -34,7 +32,7 @@ from topo.plotting.plotgroup import plotgroups, FeatureCurvePlotGroup
 from topo.misc.keyedlist import KeyedList
 from topo.misc.commandline import sim_name_from_filename
 import topo.misc.genexamples
-import topo.command.basic
+import topo.command
 
 import topo.tkgui 
 
@@ -164,7 +162,7 @@ class PlotsMenuEntry(param.Parameterized):
 
 # Notebook only available for Tkinter>=8.5
 try:
-    from param.external import Notebook
+    from paramtk.tilewrapper import Notebook
     class DockManager(Notebook):
         """Manages windows that can be tabs in a notebook, or toplevels."""
         def __init__(self, master=None, cnf={}, **kw):
@@ -243,7 +241,6 @@ except ImportError:
 # find an example of tkinter software displaying a gui exception on
 # the originating window.)
 def _tkinter_report_exception(widget):
-    import sys
     exc, val, tb = sys.exc_type, sys.exc_value, sys.exc_traceback
     msg = "(%s) %s"%(exc.__name__,val)
     # If the supplied widget has no master, it's probably the Tk
@@ -270,9 +267,16 @@ def _tkinter_report_exception(widget):
         stat.error('%s'%msg)
     else:
         topo.guimain.messageBar.error('%s'%msg)
-
+    
+    # BK-NOTE: Default is now to display full trace always. Any user
+    # errors should be caught as special exception cases 
+    
+    # BK-ALERT: Want to raise errors vs print, however this currently crashes ipython.
+    #raise
+    
     param.Parameterized().warning(msg)
-    #import traceback; traceback.print_exc()
+    import traceback
+    traceback.print_exc()
 
 
 import Tkinter
@@ -551,7 +555,11 @@ class TopoConsole(tk.AppWindow,tk.TkParameterized):
             if topo.tkgui.system_platform=="linux" and os.getenv('EMACS')!='t':
                 try: os.system("stty sane")
                 except: pass
-
+            # CEBALERT: re. above. Shouldn't we be able to store the
+            # output of "stty --save" before starting the gui, then
+            # ensure that when the gui exits (however badly it
+            # happens) run "stty saved_settings"?
+                
             # CEBALERT: there was no call to self.master.destroy()
             sys.exit(exit_status)
 
@@ -594,13 +602,13 @@ class TopoConsole(tk.AppWindow,tk.TkParameterized):
                                         initialfile=topo.sim.basename()+"_script_repr.ty")
         
         if script_name:
-            topo.command.basic.save_script_repr(script_name)
+            topo.command.save_script_repr(script_name)
             self.messageBar.response('Script saved to ' + script_name)
             
     
     def load_snapshot(self):
         """
-        Dialog to load a user-selected snapshot (see topo.command.basic.load_snapshot() ).
+        Dialog to load a user-selected snapshot (see topo.command.load_snapshot() ).
         """
         snapshot_name = askopenfilename(initialdir=normalize_path(),filetypes=SAVED_FILETYPES)
 
@@ -609,7 +617,7 @@ class TopoConsole(tk.AppWindow,tk.TkParameterized):
         else:
             self.messageBar.dynamicinfo('Loading snapshot (may take some time)...')
             self.update_idletasks()            
-            topo.command.basic.load_snapshot(snapshot_name)
+            topo.command.load_snapshot(snapshot_name)
             self.messageBar.response('Loaded snapshot ' + snapshot_name)
             self.title(topo.sim.name)
 
@@ -618,7 +626,7 @@ class TopoConsole(tk.AppWindow,tk.TkParameterized):
 
     def save_snapshot(self):
         """
-        Dialog to save a snapshot (see topo.command.basic.save_snapshot() ).
+        Dialog to save a snapshot (see topo.command.save_snapshot() ).
         
         Adds the file extension .typ if not already present.
         """
@@ -634,7 +642,7 @@ class TopoConsole(tk.AppWindow,tk.TkParameterized):
                 
             self.messageBar.dynamicinfo('Saving snapshot (may take some time)...')
             self.update_idletasks()            
-            topo.command.basic.save_snapshot(snapshot_name)
+            topo.command.save_snapshot(snapshot_name)
             self.messageBar.response('Snapshot saved to ' + snapshot_name)
     
 
@@ -764,7 +772,6 @@ class TopoConsole(tk.AppWindow,tk.TkParameterized):
         # Hack to find appropriate status bar: Go back through frames
         # until a widget with a status bar is found, and return it.
         try:
-            import sys
             while True:
                 f = sys._getframe(i)
                 if hasattr(f,'f_locals'):
